<?php
/**
 * Author: lf
 * Blog: https://blog.feehi.com
 * Email: job@feehi.com
 * Created at: 2018-01-17 12:05
 */

namespace feehi\cdn;

use Exception;
use OSS\OssClient;

class AliossTarget extends TargetAbstract implements TargetInterface
{

    public $accessKey;

    public $accessSecret;

    public $endPoint;

    public $bucket;

    /** @var  OssClient */
    public $client;

    public function init()
    {
        parent::init(); // TODO: Change the autogenerated stub
        if( empty($this->accessKey) ) throw new Exception("Alioss accessKey cannot be blank");
        if( empty($this->accessSecret) ) throw new Exception("Alioss accessSecret cannot be blank");
        if( empty($this->endPoint) ) throw new Exception("Alioss endPoint cannot be blank");
        $this->client = new OssClient($this->accessKey, $this->accessSecret, $this->endPoint);
    }

    public function upload($localFile, $destFile)
    {
        $destFile = $this->nomarlizeDestFilePath($destFile);
        try {
            $result = $this->client->uploadFile($this->bucket, $destFile, $localFile);
            return true;
        }catch (Exception $e){
            $this->lastError = $e->getMessage();
            return false;
        }
    }

    public function multiUpload($localFile, $destFile)
    {
        $destFile = $this->nomarlizeDestFilePath($destFile);
        try {
            $this->client->multiuploadFile($this->bucket, $destFile, $localFile);
            return true;
        }catch (Exception $e){
            $this->lastError = $e->getMessage();
            return false;
        }
    }

    public function exists($destFile)
    {
        if( empty($destFile) ) return false;
        $destFile = $this->nomarlizeDestFilePath($destFile);
        return $this->client->doesObjectExist($this->bucket, $destFile);
    }

    public function delete($destFile)
    {
        $destFile = $this->nomarlizeDestFilePath($destFile);
        try {
            $result = $this->client->deleteObject($this->bucket, $destFile);
            return true;
        }catch (Exception $e){
            $this->lastError = $e->getMessage();
            return false;
        }
    }

    private function nomarlizeDestFilePath($destFile)
    {
        if( strpos($destFile, '/') === 0 ) $destFile = substr($destFile, 1);
        return $destFile;
    }
}